@@ -21,10 +21,12 @@ from friendly_traceback import __version__ as ft_version
 from friendly_traceback import debug_helper
 
 from friendly import console, __version__
-from friendly import set_formatter
+from friendly import configuration
 from .my_gettext import current_lang
+configuration.ENVIRONMENT = "terminal"
+
+from friendly.rich_console_helpers import set_formatter
 
-# TODO: add friendly-traceback AND friendly version
 
 versions = "\nfriendly-traceback: {}\nfriendly: {}\nPython: {}\n".format(
     ft_version, __version__, platform.python_version()
@@ -35,7 +37,7 @@ def import_function(dotted_path: str) -> type:
     """Import a function from a module, given its dotted path.
 
     This is a utility function currently used when a custom formatter
-    is used using a command line argument::
+    is invoked by a command line argument::
 
         python -m friendly --formatter custom_formatter
     """
@@ -87,7 +89,7 @@ parser.add_argument(
 
 parser.add_argument(
     "--lang",
-    default="en",
+    default=current_lang.get_lang(),
     help="""This sets the language used by Friendly.
             Usually this is a two-letter code such as 'fr' for French.
          """,
@@ -103,7 +105,7 @@ parser.add_argument(
 parser.add_argument(
     "-f",
     "--formatter",
-    help="""Specifies an output format (bw, dark, light, docs, markown, or markdown_docs)
+    help="""Specifies an output format (bw, dark, light, docs, markdown, or markdown_docs)
     or a custom formatter function, as a dotted path. By default, the console
     will use dark if it is available.
 
@@ -165,10 +167,11 @@ def main():
             set_formatter(formatter, background=args.background)  # pragma: no cover
         else:
             set_formatter(import_function(args.formatter))
-            formatter = "dark"  # for the console - should not be needed
     else:
-        set_formatter("dark", background=args.background)
-        formatter = "dark"
+        formatter = configuration.read(key="formatter")
+        if formatter is None:
+            formatter = "dark"
+        set_formatter(formatter, background=args.background)
 
     console_defaults = {}
     if args.source is not None:
@@ -190,7 +193,6 @@ def main():
         if sys.flags.interactive:  # pragma: no cover
             console.start_console(
                 local_vars=console_defaults,
-                formatter=formatter,
                 background=args.background,
                 lang=args.lang,
                 ipython_prompt=not args.python_prompt,
@@ -199,7 +201,6 @@ def main():
     else:  # pragma: no cover
         console.start_console(
             local_vars=console_defaults,
-            formatter=formatter,
             background=args.background,
             lang=args.lang,
             ipython_prompt=not args.python_prompt,
