@@ -57,7 +57,7 @@ class FriendlyConsole(ft_console.FriendlyTracebackConsole):
         self.rich_console = False
         friendly.set_formatter(formatter, background=background)
         if formatter in ["dark", "light"]:
-            self.rich_console = session.console
+            self.rich_console = True
         self.check_for_builtins_changes()
         self.check_for_annotations()
 
@@ -68,7 +68,7 @@ class FriendlyConsole(ft_console.FriendlyTracebackConsole):
         display a traceback.  All exceptions are caught except
         SystemExit, which, unlike the case for the original version in the
         standard library, cleanly exists the program. This is done
-        so as to avoid our Friendly's exception hook to intercept
+        to avoid our Friendly's exception hook to intercept
         it and confuse the users.
 
         A note about KeyboardInterrupt: this exception may occur
@@ -195,26 +195,36 @@ class FriendlyConsole(ft_console.FriendlyTracebackConsole):
         implementation.
         """
         if self.rich_console:
-            self.rich_console.print(prompt, style="operators", end="")
-            return input()
+            if "[" in prompt:
+                prompt = f"\n[operators][[/operators]{self.counter}[operators]]: "
+            elif "...:" in prompt:
+                prompt = prompt.replace("...:", "...[operators]:[/operators]")
+            else:
+                prompt = "[operators]" + prompt
+            return session.console.input(prompt)
         return input(prompt)
 
 
 def start_console(
     local_vars=None,
-    formatter="dark",
+    formatter=None,
     include="friendly_tb",
-    lang="en",
+    lang=None,
     banner=None,
     background=None,
     displayhook=None,
     ipython_prompt=True,
 ):
     """Starts a console; modified from code.interact"""
-    # from . import config
 
+    if lang is None:
+        lang = friendly.get_lang()
     if banner is None:
         banner = BANNER + ft.ft_console.type_friendly() + "\n"
+    if formatter is None:
+        formatter = friendly.configuration.read(key="formatter")
+        if formatter is None:
+            formatter = "dark"
 
     friendly.set_lang(lang)
 
