@@ -18,12 +18,12 @@ from friendly_traceback import (
     __version__,
 )  # noqa
 
-from friendly_traceback.config import session
-
+from friendly_traceback.config import session, did_exception_occur_before
 from friendly.rich_console_helpers import *  # noqa
 from friendly.rich_console_helpers import helpers, current_lang  # noqa
 from friendly import __version__ as version  # noqa
 from friendly import current_lang  # noqa
+from friendly import configuration
 
 try:
     from IPython.utils import py3compat  # noqa
@@ -36,6 +36,7 @@ _ = current_lang.translate
 colorama.deinit()
 colorama.init(convert=False, strip=False)
 session.ipython_prompt = True
+configuration.ENVIRONMENT = "ipython"
 
 shell.InteractiveShell.showtraceback = lambda self, *args, **kwargs: explain_traceback()
 shell.InteractiveShell.showsyntaxerror = (
@@ -48,11 +49,16 @@ install(include="friendly_tb")
 # By default, we assume a terminal with a dark background.
 set_formatter("dark")  # noqa
 print(
-    f"friendly_traceback {__version__}; friendly {version}.\nType 'Friendly' for information."
+    f"friendly_traceback {__version__}; friendly {version}."
 )
 
-
 if session.exception_before_import:
-    if session.saved_info:
+    # recompile to exclude IPython's own files
+    if session.saved_info:  # should always be True; just being careful
         session.saved_info.pop()
     session.get_traceback_info(sys.last_type, sys.last_value, sys.last_traceback)
+    friendly_tb()  # noqa
+else:
+    if did_exception_occur_before():
+        friendly_tb()
+print(_("Type 'Friendly' for basic help."))
\ No newline at end of file
