@@ -23,22 +23,30 @@ gettext.translation() is the class-based API for gettext.
 import gettext
 import os
 
+from . import configuration
 from friendly_traceback import debug_helper
 
 
 class LangState:
     def __init__(self):
         self._translate = lambda text: text
-        self.lang = "en"
+        self.lang = self.get_lang()
+
+    def get_lang(self):
+        """Gets the current saved language"""
+        lang = configuration.read(key="lang", environment="common")
+        if lang is None:
+            lang = "en"
+        return lang
 
     def install(self, lang=None):
         """Sets the language to be used for translations"""
         if lang is None:
-            lang = "en"
+            lang = self.get_lang()
         try:
             # We first look for the exact language requested.
             _lang = gettext.translation(
-                "friendly",
+                "friendly_" + lang,
                 localedir=os.path.normpath(
                     os.path.join(os.path.dirname(__file__), "locales")
                 ),
@@ -51,7 +59,7 @@ class LangState:
             # generic version, such as fr, defined by a two-letter code.
             lang = lang[:2]
             _lang = gettext.translation(
-                "friendly",
+                "friendly_" + lang,
                 localedir=os.path.normpath(
                     os.path.join(os.path.dirname(__file__), "locales")
                 ),
@@ -65,9 +73,7 @@ class LangState:
 
     def translate(self, text):
         translation = self._translate(text)
-        if self.lang == "en":
-            return translation
-        if translation == text:  # pragma: no cover
+        if translation == text and self.lang == "fr":  # pragma: no cover
             debug_helper.log(f"Potentially untranslated text for {self.lang}:")
             debug_helper.log(text)
         return translation
@@ -75,35 +81,3 @@ class LangState:
 
 current_lang = LangState()  # noqa
 
-
-# Todo: replace localized messages about new cases by the function below
-# which will do the logging automatically.
-
-
-def please_report():
-    _ = current_lang.translate
-    debug_helper.log("Friendly; please_report: New case to consider.")
-    return _(
-        "Please report this example to "
-        "https://github.com/aroberge/friendly/issues.\n"
-        "If you are using a REPL, use `www('bug')` to do so.\n\n"
-    )
-
-
-def no_information():
-    _ = current_lang.translate
-    debug_helper.log("New case to consider.")
-    return (
-        _("No information is known about this exception.\n")
-        + please_report()
-        + _(
-            "If you are using the Friendly console, use `www()` to\n"
-            "do an Internet search for this particular case.\n"
-        )
-    )
-
-
-def internal_error(e):
-    _ = current_lang.translate
-    debug_helper.log("--> Internal error: " + repr(e))
-    return _("Internal error for Friendly.\n") + please_report()
