@@ -1,19 +1,21 @@
 """In this module, we modify the basic console helpers for friendly-traceback
-so as to add custom ones for Rich-based formatters."""
+to add custom ones for Rich-based formatters."""
 
 from friendly_traceback.console_helpers import *  # noqa; include Friendly below
 from friendly_traceback.console_helpers import Friendly, helpers
 from friendly_traceback.functions_help import add_help_attribute, short_description
 from friendly_traceback.config import session
 
+old_set_lang = set_lang  # noqa
+
 from friendly.my_gettext import current_lang
+from friendly import set_lang, view_saved
 
 # The following is different from the one imported via the import * above
 from friendly import set_formatter
 
 _ = current_lang.translate
 old_history = history  # noqa
-old_set_lang = set_lang  # noqa
 
 
 def history():
@@ -22,11 +24,6 @@ def history():
     session.rich_add_vspace = True
 
 
-def set_lang(lang):
-    old_set_lang(lang)
-    current_lang.install(lang)
-
-
 history.__doc__ = old_history.__doc__
 set_lang.__doc__ = old_set_lang.__doc__
 helpers["history"] = history
@@ -89,7 +86,8 @@ short_description["light"] = lambda: _(
 )
 short_description["plain"] = lambda: _("Plain formatting, with no colours added.")
 short_description["set_width"] = lambda: _("Sets the output width in some modes.")
-local_helpers = {"dark": dark, "light": light, "plain": plain, "set_width": set_width}
+short_description["view_saved"] = lambda : _("Prints the saved configuration.")
+local_helpers = {"dark": dark, "light": light, "plain": plain, "set_width": set_width, "view_saved": view_saved}
 add_help_attribute(local_helpers)
 for helper in local_helpers:
     Friendly.add_helper(local_helpers[helper])
